==> zither-1.1.20.tar.gz: zither_prj/zither/print_conf.c <==

#include<stdio.h>
#include<unistd.h>
#include<netinet/in.h>
#include<string.h>
#include<stdlib.h>
#include<pthread.h>


#include"zither.h"
#include<almemsys/almemsys.h>


extern global_data_t gd;


int print_conf(void)
{
   fprintf(stdout,"-- ZITHER Configration setup list --\n");
   fprintf(stdout,"-- *Config File                                = %s\n", gd.fp.conf_path);
   fprintf(stdout,"-- *Neg File                                   = %s\n", gd.fp.neg_conf);
   fprintf(stdout,"-- SOCK_IPADDR    (bind ip)                    = %s\n", gd.ms.ip_addr);
   fprintf(stdout,"-- SOCK_PORT      (listen port)                = %d\n",gd.ms.port);
   fprintf(stdout,"-- PRO_COUNT      (thread connection max)      = %d\n",gd.ms.max_count);
   fprintf(stdout,"-- ERR_LOG        (err log path)               = %s\n",gd.fp.errlog);
   fprintf(stdout,"-- CON_LOG        (connection log path)        = %s\n",gd.fp.connectlog);
   fprintf(stdout,"-- FILE_LOCK      (connection lock path)       = %s\n",gd.fp.lock_path);
   fprintf(stdout,"-- CFILE_LOCK     (connection lost lock path)  = %s\n",gd.fp.clock_path);
   fprintf(stdout,"-- FILE_CONF      (configtation path)          = %s\n",gd.fp.file_conf);
   fprintf(stdout,"-- MAIL_FROM      (base mail from)             = %s\n",gd.md.ch_MailFrom);
   fprintf(stdout,"-- MAIL_RCPTTO    (base mail To:)              = %s\n",gd.md.ch_MailRcptTo);
   fprintf(stdout,"-- MAIL_SERV      (mail server)                = %s\n",gd.md.ch_MailServ);
   fprintf(stdout,"-- MAIL_CC        (base mail Cc:)              = %s\n",gd.md.ch_MailCc);
   fprintf(stdout,"-- LIFE_INT       (base life interval sec)     = %d\n",gd.bs.life_int);
   fprintf(stdout,"-- LIFE_LOS       (base life interval los sec) = %d\n",gd.bs.life_los);
   fprintf(stdout,"-- UID            (exec user id)               = %d\n",gd.exid.uid);
   fprintf(stdout,"-- MAIL_ONOFF     (mail on or off switch)      = %d\n",gd.md.in_mailonoff);
   fprintf(stdout,"-- PG_DATA        (Postgresql connection data) = %s\n",gd.pg.postgres_data);
   fprintf(stdout,"-- PG_WEB         (applon web addrses)         = %s\n",gd.pg.pg_webserver);
   fprintf(stdout,"-- MYSQL_SERVER   (mysql connection address)   = %s\n",gd.mysql.mysql_server);
   fprintf(stdout,"-- MYSQL_USERNAME (mysql user name)            = %s\n",gd.mysql.mysql_username);
   fprintf(stdout,"-- MYSQL_PASSWORD (mysql user password)        = %s\n",gd.mysql.mysql_password);
   fprintf(stdout,"-- MYSQL_DB       (mysql database name)        = %s\n",gd.mysql.mysql_db);
   fprintf(stdout,"-- DB_SELECT      (select db 'PGSQL'or'MYSQL') = %s\n",gd.db_select);
   fprintf(stdout,"-- ON_BCC         (select bcc address)         = %s\n",gd.on_bcc);
   fprintf(stdout,"-- CRON_ONOFF     (enable cron mode 1)         = %d\n",gd.cron_onoff);

   fprintf(stdout,"Version %s\n", CL_VAR);

return 0;
}

==> zither-1.2.1.tar.gz: zither_prj/zither/print_conf.c <==

#include<stdio.h>
#include<unistd.h>
#include<netinet/in.h>
#include<string.h>
#include<stdlib.h>
#include<pthread.h>


#include"zither.h"
#include<almemsys/almemsys.h>


extern global_data_t gd;


int print_conf(void)
{
   fprintf(stdout,"-- ZITHER Configration setup list --\n");
   fprintf(stdout,"-- *Config File                                = %s\n", gd.fp.conf_path);
   fprintf(stdout,"-- *Neg File                                   = %s\n", gd.fp.neg_conf);
   fprintf(stdout,"-- SOCK_IPADDR    (bind ip)                    = %s\n", gd.ms.ip_addr);
   fprintf(stdout,"-- SOCK_PORT      (listen port)                = %d\n",gd.ms.port);
   fprintf(stdout,"-- PRO_COUNT      (thread connection max)      = %d\n",gd.ms.max_count);
   fprintf(stdout,"-- ERR_LOG        (err log path)               = %s\n",gd.fp.errlog);
   fprintf(stdout,"-- CON_LOG        (connection log path)        = %s\n",gd.fp.connectlog);
   fprintf(stdout,"-- FILE_LOCK      (connection lock path)       = %s\n",gd.fp.lock_path);
   fprintf(stdout,"-- CFILE_LOCK     (connection lost lock path)  = %s\n",gd.fp.clock_path);
   fprintf(stdout,"-- FILE_CONF      (configtation path)          = %s\n",gd.fp.file_conf);
   fprintf(stdout,"-- MAIL_FROM      (base mail from)             = %s\n",gd.md.ch_MailFrom);
   fprintf(stdout,"-- MAIL_RCPTTO    (base mail To:)              = %s\n",gd.md.ch_MailRcptTo);
   fprintf(stdout,"-- MAIL_SERV      (mail server)                = %s\n",gd.md.ch_MailServ);
   fprintf(stdout,"-- MAIL_CC        (base mail Cc:)              = %s\n",gd.md.ch_MailCc);
   fprintf(stdout,"-- LIFE_INT       (base life interval sec)     = %d\n",gd.bs.life_int);
   fprintf(stdout,"-- LIFE_LOS       (base life interval los sec) = %d\n",gd.bs.life_los);
   fprintf(stdout,"-- UID            (exec user id)               = %d\n",gd.exid.uid);
   fprintf(stdout,"-- MAIL_ONOFF     (mail on or off switch)      = %d\n",gd.md.in_mailonoff);
   fprintf(stdout,"-- PG_DATA        (Postgresql connection data) = %s\n",gd.pg.postgres_data);
   fprintf(stdout,"-- PG_WEB         (applon web addrses)         = %s\n",gd.pg.pg_webserver);
   fprintf(stdout,"-- MYSQL_SERVER   (mysql connection address)   = %s\n",gd.mysql.mysql_server);
   fprintf(stdout,"-- MYSQL_USERNAME (mysql user name)            = %s\n",gd.mysql.mysql_username);
   fprintf(stdout,"-- MYSQL_PASSWORD (mysql user password)        = %s\n",gd.mysql.mysql_password);
   fprintf(stdout,"-- MYSQL_DB       (mysql database name)        = %s\n",gd.mysql.mysql_db);
   fprintf(stdout,"-- DB_SELECT      (select db 'PGSQL'or'MYSQL') = %s\n",gd.db_select);
   fprintf(stdout,"-- ON_BCC         (select bcc address)         = %s\n",gd.on_bcc);
   fprintf(stdout,"-- CRON_ONOFF     (enable cron mode 1)         = %d\n",gd.cron_onoff);
   #ifdef SIGNATURE_MODE
   fprintf(stdout,"-- SIG_FILENAME   (mail signature list file)   = %s\n",gd.sig.sig_filename);
   fprintf(stdout,"-- SIG_INTERVAL   (mail signature set interval)= %d\n",gd.sig.sig_interval);
   #endif
   fprintf(stdout,"Version %s\n", CL_VAR);

return 0;
}
